Package: qtlnet
Version: 1.5.4
Date: 2020-04-12
Author: Elias Chaibub Neto <echaibub@hotmail.com> and Brian S. yandell <brian.yandell@wisc.edu>
Title: Causal Inference of QTL Networks
Description: Functions to Simultaneously Infer Causal Graphs and Genetic Architecture.
  Includes acyclic and cyclic graphs for data from an experimental cross with a modest number (<10) of phenotypes driven by
  a few genetic loci (QTL).
  Chaibub Neto E, Keller MP, Attie AD, Yandell BS (2010)
  Causal Graphical Models in Systems Genetics: a unified framework for joint inference of causal network and genetic architecture for correlated phenotypes.
  Annals of Applied Statistics 4: 320-339.
  <doi:10.1214/09-AOAS288>.
Maintainer: Brian S. Yandell <brian.yandell@wisc.edu>
Depends: qtl,igraph,sem,graph,pcalg, R (>= 2.10)
LazyLoad: yes
LazyData: yes
License: GPL (>= 2)
URL: http://www.stat.wisc.edu/~yandell/sysgen
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2020-04-12 21:55:28 UTC; brianyandell
Repository: CRAN
Date/Publication: 2020-04-13 04:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 06:43:23 UTC; unix
